import React, { useState, useContext } from "react";
import Button from "react-bootstrap/Button";
import Form from "react-bootstrap/Form";
import Container from "react-bootstrap/Container";
import { signin } from "./api-auth";
import auth from "./auth-helpers";
import { Redirect, useHistory } from "react-router-dom";
import { AuthContext } from "./auth-context";

function Signin() {
  const authContext = useContext(AuthContext)
  // const history = useHistory()
  const [values, setValues] = useState({
    email: "",
    password: "",
    error: "",
    redirect: false,
  });

  const handleChange = (name) => (event) => {
    setValues({ ...values, [name]: event.target.value });
  };

  const clickSubmit = (event) => {
    event.preventDefault()
    const user = {
      email: values.email || undefined,
      password: values.password || undefined,
    };

    console.log('authContext in Signin.jsx:', authContext)

    signin(user).then((data) => {
      if (data.error) {
        setValues({ ...values, error: data.error });
      } else {
        auth.authenticate(data, () => {
          authContext.setAuthState(auth.isAuthenticated())
          setValues({ ...values, error: "", redirect: true });
        });
      }
    });
  };

  if (values.redirect) {
    return <Redirect to='/' />
  }  

  return (
    <Container className="col-sm-6 col-md-5 col-lg-4 p-5">
      <Form>
        <Form.Group controlId="email">
          <Form.Label>Email</Form.Label>
          <Form.Control
            type="email"
            placeholder="Enter email"
            onChange={handleChange('email')}
          />
          <Form.Text className="text-muted">
            We'll never share your email with anyone else.
          </Form.Text>
        </Form.Group>

        <Form.Group controlId="password">
          <Form.Label>Password</Form.Label>
          <Form.Control
            type="password"
            placeholder="Password"
            onChange={handleChange('password')}
          />
        </Form.Group>

        <Button variant="primary" type="submit" onClick={clickSubmit}>
          Submit
        </Button>
      </Form>
    </Container>
  );
}

export default Signin;
